crocoite
========

.. code:: bash

    pip install crocoite pywb
    crocoite http://example.com/ example.com.warc.gz
    wb-manager init test && wb-manager add test example.com.warc.gz
    wayback &
    $BROWSER http://localhost:8080

See documentation_ for more information.

.. _documentation: https://6xq.net/crocoite/

